@@ -6,7 +6,6 @@ package actions
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
 
 	"github.com/stretchr/testify/assert"
@@ -15,16 +14,16 @@ import (
 func TestGetLatestRunnerToken(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 	token := unittest.AssertExistsAndLoadBean(t, &ActionRunnerToken{ID: 3})
-	expectedToken, err := GetLatestRunnerToken(db.DefaultContext, 1, 0)
+	expectedToken, err := GetLatestRunnerToken(t.Context(), 1, 0)
 	assert.NoError(t, err)
 	assert.Equal(t, expectedToken, token)
 }
 
 func TestNewRunnerToken(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
-	token, err := NewRunnerToken(db.DefaultContext, 1, 0)
+	token, err := NewRunnerToken(t.Context(), 1, 0)
 	assert.NoError(t, err)
-	expectedToken, err := GetLatestRunnerToken(db.DefaultContext, 1, 0)
+	expectedToken, err := GetLatestRunnerToken(t.Context(), 1, 0)
 	assert.NoError(t, err)
 	assert.Equal(t, expectedToken, token)
 }
@@ -33,8 +32,8 @@ func TestUpdateRunnerToken(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 	token := unittest.AssertExistsAndLoadBean(t, &ActionRunnerToken{ID: 3})
 	token.IsActive = true
-	assert.NoError(t, UpdateRunnerToken(db.DefaultContext, token))
-	expectedToken, err := GetLatestRunnerToken(db.DefaultContext, 1, 0)
+	assert.NoError(t, UpdateRunnerToken(t.Context(), token))
+	expectedToken, err := GetLatestRunnerToken(t.Context(), 1, 0)
 	assert.NoError(t, err)
 	assert.Equal(t, expectedToken, token)
 }
