@@ -6,7 +6,6 @@ package issues_test
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	issues_model "code.gitea.io/gitea/models/issues"
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
@@ -22,7 +21,7 @@ func TestNewIssueLabelsScope(t *testing.T) {
 	label2 := unittest.AssertExistsAndLoadBean(t, &issues_model.Label{ID: 8})
 	doer := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 2})
 
-	assert.NoError(t, issues_model.NewIssueLabels(db.DefaultContext, issue, []*issues_model.Label{label1, label2}, doer))
+	assert.NoError(t, issues_model.NewIssueLabels(t.Context(), issue, []*issues_model.Label{label1, label2}, doer))
 
 	assert.Len(t, issue.Labels, 1)
 	assert.Equal(t, label2.ID, issue.Labels[0].ID)
