@@ -1,7 +1,7 @@
-// Copyright 2023 The Gitea Authors. All rights reserved.
+// Copyright 2021 The Gitea Authors. All rights reserved.
 // SPDX-License-Identifier: MIT
 
-package v1_22 //nolint
+package v1_19
 
 import (
 	"testing"
