@@ -12,6 +12,7 @@ import (
 	repo_model "code.gitea.io/gitea/models/repo"
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
+	"code.gitea.io/gitea/modules/setting"
 
 	"github.com/stretchr/testify/assert"
 )
@@ -35,34 +36,41 @@ func TestAccessLevel(t *testing.T) {
 	// org. owned private repo
 	repo24 := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 24})
 
-	level, err := access_model.AccessLevel(db.DefaultContext, user2, repo1)
+	level, err := access_model.AccessLevel(t.Context(), user2, repo1)
 	assert.NoError(t, err)
 	assert.Equal(t, perm_model.AccessModeOwner, level)
 
-	level, err = access_model.AccessLevel(db.DefaultContext, user2, repo3)
+	level, err = access_model.AccessLevel(t.Context(), user2, repo3)
 	assert.NoError(t, err)
 	assert.Equal(t, perm_model.AccessModeOwner, level)
 
-	level, err = access_model.AccessLevel(db.DefaultContext, user5, repo1)
+	level, err = access_model.AccessLevel(t.Context(), user5, repo1)
 	assert.NoError(t, err)
 	assert.Equal(t, perm_model.AccessModeRead, level)
 
-	level, err = access_model.AccessLevel(db.DefaultContext, user5, repo3)
+	level, err = access_model.AccessLevel(t.Context(), user5, repo3)
 	assert.NoError(t, err)
 	assert.Equal(t, perm_model.AccessModeNone, level)
 
-	// restricted user has no access to a public repo
-	level, err = access_model.AccessLevel(db.DefaultContext, user29, repo1)
+	// restricted user has default access to a public repo if no sign-in is required
+	setting.Service.RequireSignInViewStrict = false
+	level, err = access_model.AccessLevel(t.Context(), user29, repo1)
+	assert.NoError(t, err)
+	assert.Equal(t, perm_model.AccessModeRead, level)
+
+	// restricted user has no access to a public repo if sign-in is required
+	setting.Service.RequireSignInViewStrict = true
+	level, err = access_model.AccessLevel(t.Context(), user29, repo1)
 	assert.NoError(t, err)
 	assert.Equal(t, perm_model.AccessModeNone, level)
 
 	// ... unless he's a collaborator
-	level, err = access_model.AccessLevel(db.DefaultContext, user29, repo4)
+	level, err = access_model.AccessLevel(t.Context(), user29, repo4)
 	assert.NoError(t, err)
 	assert.Equal(t, perm_model.AccessModeWrite, level)
 
 	// ... or a team member
-	level, err = access_model.AccessLevel(db.DefaultContext, user29, repo24)
+	level, err = access_model.AccessLevel(t.Context(), user29, repo24)
 	assert.NoError(t, err)
 	assert.Equal(t, perm_model.AccessModeRead, level)
 }
@@ -79,17 +87,17 @@ func TestHasAccess(t *testing.T) {
 	repo2 := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 3})
 	assert.True(t, repo2.IsPrivate)
 
-	has, err := access_model.HasAnyUnitAccess(db.DefaultContext, user1.ID, repo1)
+	has, err := access_model.HasAnyUnitAccess(t.Context(), user1.ID, repo1)
 	assert.NoError(t, err)
 	assert.True(t, has)
 
-	_, err = access_model.HasAnyUnitAccess(db.DefaultContext, user1.ID, repo2)
+	_, err = access_model.HasAnyUnitAccess(t.Context(), user1.ID, repo2)
 	assert.NoError(t, err)
 
-	_, err = access_model.HasAnyUnitAccess(db.DefaultContext, user2.ID, repo1)
+	_, err = access_model.HasAnyUnitAccess(t.Context(), user2.ID, repo1)
 	assert.NoError(t, err)
 
-	_, err = access_model.HasAnyUnitAccess(db.DefaultContext, user2.ID, repo2)
+	_, err = access_model.HasAnyUnitAccess(t.Context(), user2.ID, repo2)
 	assert.NoError(t, err)
 }
 
@@ -97,14 +105,14 @@ func TestRepository_RecalculateAccesses(t *testing.T) {
 	// test with organization repo
 	assert.NoError(t, unittest.PrepareTestDatabase())
 	repo1 := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 3})
-	assert.NoError(t, repo1.LoadOwner(db.DefaultContext))
+	assert.NoError(t, repo1.LoadOwner(t.Context()))
 
-	_, err := db.GetEngine(db.DefaultContext).Delete(&repo_model.Collaboration{UserID: 2, RepoID: 3})
+	_, err := db.GetEngine(t.Context()).Delete(&repo_model.Collaboration{UserID: 2, RepoID: 3})
 	assert.NoError(t, err)
-	assert.NoError(t, access_model.RecalculateAccesses(db.DefaultContext, repo1))
+	assert.NoError(t, access_model.RecalculateAccesses(t.Context(), repo1))
 
 	access := &access_model.Access{UserID: 2, RepoID: 3}
-	has, err := db.GetEngine(db.DefaultContext).Get(access)
+	has, err := db.GetEngine(t.Context()).Get(access)
 	assert.NoError(t, err)
 	assert.True(t, has)
 	assert.Equal(t, perm_model.AccessModeOwner, access.Mode)
@@ -114,13 +122,13 @@ func TestRepository_RecalculateAccesses2(t *testing.T) {
 	// test with non-organization repo
 	assert.NoError(t, unittest.PrepareTestDatabase())
 	repo1 := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 4})
-	assert.NoError(t, repo1.LoadOwner(db.DefaultContext))
+	assert.NoError(t, repo1.LoadOwner(t.Context()))
 
-	_, err := db.GetEngine(db.DefaultContext).Delete(&repo_model.Collaboration{UserID: 4, RepoID: 4})
+	_, err := db.GetEngine(t.Context()).Delete(&repo_model.Collaboration{UserID: 4, RepoID: 4})
 	assert.NoError(t, err)
-	assert.NoError(t, access_model.RecalculateAccesses(db.DefaultContext, repo1))
+	assert.NoError(t, access_model.RecalculateAccesses(t.Context(), repo1))
 
-	has, err := db.GetEngine(db.DefaultContext).Get(&access_model.Access{UserID: 4, RepoID: 4})
+	has, err := db.GetEngine(t.Context()).Get(&access_model.Access{UserID: 4, RepoID: 4})
 	assert.NoError(t, err)
 	assert.False(t, has)
 }
