@@ -6,7 +6,6 @@ package activitypub
 import (
 	"testing"
 
-	"code.gitea.io/gitea/models/db"
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
 
@@ -18,12 +17,12 @@ import (
 func TestUserSettings(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
 	user1 := unittest.AssertExistsAndLoadBean(t, &user_model.User{ID: 1})
-	pub, priv, err := GetKeyPair(db.DefaultContext, user1)
+	pub, priv, err := GetKeyPair(t.Context(), user1)
 	assert.NoError(t, err)
-	pub1, err := GetPublicKey(db.DefaultContext, user1)
+	pub1, err := GetPublicKey(t.Context(), user1)
 	assert.NoError(t, err)
 	assert.Equal(t, pub, pub1)
-	priv1, err := GetPrivateKey(db.DefaultContext, user1)
+	priv1, err := GetPrivateKey(t.Context(), user1)
 	assert.NoError(t, err)
 	assert.Equal(t, priv, priv1)
 }
