@@ -58,7 +58,7 @@ func TestParseTreeEntriesLong(t *testing.T) {
 		assert.NoError(t, err)
 		assert.Len(t, entries, len(testCase.Expected))
 		for i, entry := range entries {
-			assert.EqualValues(t, testCase.Expected[i], entry)
+			assert.Equal(t, testCase.Expected[i], entry)
 		}
 	}
 }
@@ -91,7 +91,7 @@ func TestParseTreeEntriesShort(t *testing.T) {
 		assert.NoError(t, err)
 		assert.Len(t, entries, len(testCase.Expected))
 		for i, entry := range entries {
-			assert.EqualValues(t, testCase.Expected[i], entry)
+			assert.Equal(t, testCase.Expected[i], entry)
 		}
 	}
 }
