@@ -21,11 +21,6 @@ type Tag struct {
 	Signature *CommitSignature
 }
 
-// Commit return the commit of the tag reference
-func (tag *Tag) Commit(gitRepo *Repository) (*Commit, error) {
-	return gitRepo.getCommit(tag.Object)
-}
-
 func parsePayloadSignature(data []byte, messageStart int) (payload, msg, sign string) {
 	pos := messageStart
 	signStart, signEnd := -1, -1
