@@ -29,7 +29,7 @@ import (
 )
 
 // IndexerMetadata is used to send data to the queue, so it contains only the ids.
-// It may look weired, because it has to be compatible with the old queue data format.
+// It may look weird, because it has to be compatible with the old queue data format.
 // If the IsDelete flag is true, the IDs specify the issues to delete from the index without querying the database.
 // If the IsDelete flag is false, the ID specify the issue to index, so Indexer will query the database to get the issue data.
 // It should be noted that if the id is not existing in the database, it's index will be deleted too even if IsDelete is false.
@@ -218,7 +218,7 @@ func PopulateIssueIndexer(ctx context.Context) error {
 			return fmt.Errorf("shutdown before completion: %w", ctx.Err())
 		default:
 		}
-		repos, _, err := repo_model.SearchRepositoryByName(ctx, &repo_model.SearchRepoOptions{
+		repos, _, err := repo_model.SearchRepositoryByName(ctx, repo_model.SearchRepoOptions{
 			ListOptions: db_model.ListOptions{Page: page, PageSize: repo_model.RepositoryListDefaultPageSize},
 			OrderBy:     db_model.SearchOrderByID,
 			Private:     true,
