@@ -12,6 +12,7 @@ import (
 
 	"code.gitea.io/gitea/modules/indexer/issues/internal"
 	"code.gitea.io/gitea/modules/indexer/issues/internal/tests"
+	"code.gitea.io/gitea/modules/json"
 
 	"github.com/meilisearch/meilisearch-go"
 	"github.com/stretchr/testify/assert"
@@ -45,30 +46,42 @@ func TestMeilisearchIndexer(t *testing.T) {
 }
 
 func TestConvertHits(t *testing.T) {
+	convert := func(d any) []byte {
+		b, _ := json.Marshal(d)
+		return b
+	}
+
 	_, err := convertHits(&meilisearch.SearchResponse{
-		Hits: []any{"aa", "bb", "cc", "dd"},
+		Hits: []meilisearch.Hit{
+			{
+				"aa": convert(1),
+				"bb": convert(2),
+				"cc": convert(3),
+				"dd": convert(4),
+			},
+		},
 	})
 	assert.ErrorIs(t, err, ErrMalformedResponse)
 
 	validResponse := &meilisearch.SearchResponse{
-		Hits: []any{
-			map[string]any{
-				"id":       float64(11),
-				"title":    "a title",
-				"content":  "issue body with no match",
-				"comments": []any{"hey whats up?", "I'm currently bowling", "nice"},
+		Hits: []meilisearch.Hit{
+			{
+				"id":       convert(float64(11)),
+				"title":    convert("a title"),
+				"content":  convert("issue body with no match"),
+				"comments": convert([]any{"hey whats up?", "I'm currently bowling", "nice"}),
 			},
-			map[string]any{
-				"id":       float64(22),
-				"title":    "Bowling as title",
-				"content":  "",
-				"comments": []any{},
+			{
+				"id":       convert(float64(22)),
+				"title":    convert("Bowling as title"),
+				"content":  convert(""),
+				"comments": convert([]any{}),
 			},
-			map[string]any{
-				"id":       float64(33),
-				"title":    "Bowl-ing as fuzzy match",
-				"content":  "",
-				"comments": []any{},
+			{
+				"id":       convert(float64(33)),
+				"title":    convert("Bowl-ing as fuzzy match"),
+				"content":  convert(""),
+				"comments": convert([]any{}),
 			},
 		},
 	}
