@@ -7,7 +7,6 @@ import (
 	"testing"
 	"time"
 
-	"code.gitea.io/gitea/models/db"
 	repo_model "code.gitea.io/gitea/models/repo"
 	"code.gitea.io/gitea/models/unittest"
 	"code.gitea.io/gitea/modules/queue"
@@ -33,7 +32,7 @@ func TestRepoStatsIndex(t *testing.T) {
 	err := Init()
 	assert.NoError(t, err)
 
-	repo, err := repo_model.GetRepositoryByID(db.DefaultContext, 1)
+	repo, err := repo_model.GetRepositoryByID(t.Context(), 1)
 	assert.NoError(t, err)
 
 	err = UpdateRepoIndexer(repo)
@@ -41,10 +40,10 @@ func TestRepoStatsIndex(t *testing.T) {
 
 	assert.NoError(t, queue.GetManager().FlushAll(t.Context(), 5*time.Second))
 
-	status, err := repo_model.GetIndexerStatus(db.DefaultContext, repo, repo_model.RepoIndexerTypeStats)
+	status, err := repo_model.GetIndexerStatus(t.Context(), repo, repo_model.RepoIndexerTypeStats)
 	assert.NoError(t, err)
 	assert.Equal(t, "65f1bf27bc3bf70f64657658635e66094edbcb4d", status.CommitSha)
-	langs, err := repo_model.GetTopLanguageStats(db.DefaultContext, repo, 5)
+	langs, err := repo_model.GetTopLanguageStats(t.Context(), repo, 5)
 	assert.NoError(t, err)
 	assert.Empty(t, langs)
 }
