@@ -4,7 +4,6 @@
 package markup
 
 import (
-	"context"
 	"strings"
 	"testing"
 
@@ -24,8 +23,8 @@ func TestRenderCSV(t *testing.T) {
 
 	for k, v := range kases {
 		var buf strings.Builder
-		err := render.Render(markup.NewRenderContext(context.Background()), strings.NewReader(k), &buf)
+		err := render.Render(markup.NewRenderContext(t.Context()), strings.NewReader(k), &buf)
 		assert.NoError(t, err)
-		assert.EqualValues(t, v, buf.String())
+		assert.Equal(t, v, buf.String())
 	}
 }
