@@ -41,12 +41,10 @@ func SyncRepoBranchesWithRepo(ctx context.Context, repo *repo_model.Repository,
 	if err != nil {
 		return 0, fmt.Errorf("GetObjectFormat: %w", err)
 	}
-
-	if repo.ObjectFormatName != objFmt.Name() {
+	if objFmt.Name() != repo.ObjectFormatName {
 		repo.ObjectFormatName = objFmt.Name()
-		_, err = db.GetEngine(ctx).ID(repo.ID).NoAutoTime().Update(&repo_model.Repository{ObjectFormatName: objFmt.Name()})
-		if err != nil {
-			return 0, fmt.Errorf("UpdateRepository: %w", err)
+		if err = repo_model.UpdateRepositoryColsWithAutoTime(ctx, repo, "object_format_name"); err != nil {
+			return 0, fmt.Errorf("UpdateRepositoryColsWithAutoTime: %w", err)
 		}
 	}
 
