@@ -16,16 +16,16 @@ import (
 
 func TestSyncRepoBranches(t *testing.T) {
 	assert.NoError(t, unittest.PrepareTestDatabase())
-	_, err := db.GetEngine(db.DefaultContext).ID(1).Update(&repo_model.Repository{ObjectFormatName: "bad-fmt"})
-	assert.NoError(t, db.TruncateBeans(db.DefaultContext, &git_model.Branch{}))
+	_, err := db.GetEngine(t.Context()).ID(1).Update(&repo_model.Repository{ObjectFormatName: "bad-fmt"})
+	assert.NoError(t, db.TruncateBeans(t.Context(), &git_model.Branch{}))
 	assert.NoError(t, err)
 	repo := unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 1})
 	assert.Equal(t, "bad-fmt", repo.ObjectFormatName)
-	_, err = SyncRepoBranches(db.DefaultContext, 1, 0)
+	_, err = SyncRepoBranches(t.Context(), 1, 0)
 	assert.NoError(t, err)
 	repo = unittest.AssertExistsAndLoadBean(t, &repo_model.Repository{ID: 1})
 	assert.Equal(t, "sha1", repo.ObjectFormatName)
-	branch, err := git_model.GetBranch(db.DefaultContext, 1, "master")
+	branch, err := git_model.GetBranch(t.Context(), 1, "master")
 	assert.NoError(t, err)
 	assert.Equal(t, "master", branch.Name)
 }
