@@ -74,9 +74,9 @@ func PostCronTask(ctx *context.APIContext) {
 	//     "$ref": "#/responses/empty"
 	//   "404":
 	//     "$ref": "#/responses/notFound"
-	task := cron.GetTask(ctx.PathParam(":task"))
+	task := cron.GetTask(ctx.PathParam("task"))
 	if task == nil {
-		ctx.NotFound()
+		ctx.APIErrorNotFound()
 		return
 	}
 	task.Run()
