@@ -4,6 +4,7 @@
 package repo
 
 import (
+	"errors"
 	"net/http"
 
 	"code.gitea.io/gitea/modules/git"
@@ -39,7 +40,7 @@ func ListGitHooks(ctx *context.APIContext) {
 
 	hooks, err := ctx.Repo.GitRepo.Hooks()
 	if err != nil {
-		ctx.Error(http.StatusInternalServerError, "Hooks", err)
+		ctx.APIErrorInternal(err)
 		return
 	}
 
@@ -79,13 +80,13 @@ func GetGitHook(ctx *context.APIContext) {
 	//   "404":
 	//     "$ref": "#/responses/notFound"
 
-	hookID := ctx.PathParam(":id")
+	hookID := ctx.PathParam("id")
 	hook, err := ctx.Repo.GitRepo.GetHook(hookID)
 	if err != nil {
-		if err == git.ErrNotValidHook {
-			ctx.NotFound()
+		if errors.Is(err, git.ErrNotValidHook) {
+			ctx.APIErrorNotFound()
 		} else {
-			ctx.Error(http.StatusInternalServerError, "GetHook", err)
+			ctx.APIErrorInternal(err)
 		}
 		return
 	}
@@ -126,20 +127,20 @@ func EditGitHook(ctx *context.APIContext) {
 	//     "$ref": "#/responses/notFound"
 
 	form := web.GetForm(ctx).(*api.EditGitHookOption)
-	hookID := ctx.PathParam(":id")
+	hookID := ctx.PathParam("id")
 	hook, err := ctx.Repo.GitRepo.GetHook(hookID)
 	if err != nil {
-		if err == git.ErrNotValidHook {
-			ctx.NotFound()
+		if errors.Is(err, git.ErrNotValidHook) {
+			ctx.APIErrorNotFound()
 		} else {
-			ctx.Error(http.StatusInternalServerError, "GetHook", err)
+			ctx.APIErrorInternal(err)
 		}
 		return
 	}
 
 	hook.Content = form.Content
 	if err = hook.Update(); err != nil {
-		ctx.Error(http.StatusInternalServerError, "hook.Update", err)
+		ctx.APIErrorInternal(err)
 		return
 	}
 
@@ -175,20 +176,20 @@ func DeleteGitHook(ctx *context.APIContext) {
 	//   "404":
 	//     "$ref": "#/responses/notFound"
 
-	hookID := ctx.PathParam(":id")
+	hookID := ctx.PathParam("id")
 	hook, err := ctx.Repo.GitRepo.GetHook(hookID)
 	if err != nil {
-		if err == git.ErrNotValidHook {
-			ctx.NotFound()
+		if errors.Is(err, git.ErrNotValidHook) {
+			ctx.APIErrorNotFound()
 		} else {
-			ctx.Error(http.StatusInternalServerError, "GetHook", err)
+			ctx.APIErrorInternal(err)
 		}
 		return
 	}
 
 	hook.Content = ""
 	if err = hook.Update(); err != nil {
-		ctx.Error(http.StatusInternalServerError, "hook.Update", err)
+		ctx.APIErrorInternal(err)
 		return
 	}
 
