@@ -51,13 +51,13 @@ func ListLabels(ctx *context.APIContext) {
 
 	labels, err := issues_model.GetLabelsByRepoID(ctx, ctx.Repo.Repository.ID, ctx.FormString("sort"), utils.GetListOptions(ctx))
 	if err != nil {
-		ctx.Error(http.StatusInternalServerError, "GetLabelsByRepoID", err)
+		ctx.APIErrorInternal(err)
 		return
 	}
 
 	count, err := issues_model.CountLabelsByRepoID(ctx, ctx.Repo.Repository.ID)
 	if err != nil {
-		ctx.InternalServerError(err)
+		ctx.APIErrorInternal(err)
 		return
 	}
 
@@ -99,7 +99,7 @@ func GetLabel(ctx *context.APIContext) {
 		l   *issues_model.Label
 		err error
 	)
-	strID := ctx.PathParam(":id")
+	strID := ctx.PathParam("id")
 	if intID, err2 := strconv.ParseInt(strID, 10, 64); err2 != nil {
 		l, err = issues_model.GetLabelInRepoByName(ctx, ctx.Repo.Repository.ID, strID)
 	} else {
@@ -107,9 +107,9 @@ func GetLabel(ctx *context.APIContext) {
 	}
 	if err != nil {
 		if issues_model.IsErrRepoLabelNotExist(err) {
-			ctx.NotFound()
+			ctx.APIErrorNotFound()
 		} else {
-			ctx.Error(http.StatusInternalServerError, "GetLabelByRepoID", err)
+			ctx.APIErrorInternal(err)
 		}
 		return
 	}
@@ -153,7 +153,7 @@ func CreateLabel(ctx *context.APIContext) {
 
 	color, err := label.NormalizeColor(form.Color)
 	if err != nil {
-		ctx.Error(http.StatusUnprocessableEntity, "StringToColor", err)
+		ctx.APIError(http.StatusUnprocessableEntity, err)
 		return
 	}
 	form.Color = color
@@ -166,7 +166,7 @@ func CreateLabel(ctx *context.APIContext) {
 	}
 	l.SetArchived(form.IsArchived)
 	if err := issues_model.NewLabel(ctx, l); err != nil {
-		ctx.Error(http.StatusInternalServerError, "NewLabel", err)
+		ctx.APIErrorInternal(err)
 		return
 	}
 
@@ -212,12 +212,12 @@ func EditLabel(ctx *context.APIContext) {
 	//     "$ref": "#/responses/validationError"
 
 	form := web.GetForm(ctx).(*api.EditLabelOption)
-	l, err := issues_model.GetLabelInRepoByID(ctx, ctx.Repo.Repository.ID, ctx.PathParamInt64(":id"))
+	l, err := issues_model.GetLabelInRepoByID(ctx, ctx.Repo.Repository.ID, ctx.PathParamInt64("id"))
 	if err != nil {
 		if issues_model.IsErrRepoLabelNotExist(err) {
-			ctx.NotFound()
+			ctx.APIErrorNotFound()
 		} else {
-			ctx.Error(http.StatusInternalServerError, "GetLabelByRepoID", err)
+			ctx.APIErrorInternal(err)
 		}
 		return
 	}
@@ -231,7 +231,7 @@ func EditLabel(ctx *context.APIContext) {
 	if form.Color != nil {
 		color, err := label.NormalizeColor(*form.Color)
 		if err != nil {
-			ctx.Error(http.StatusUnprocessableEntity, "StringToColor", err)
+			ctx.APIError(http.StatusUnprocessableEntity, err)
 			return
 		}
 		l.Color = color
@@ -241,7 +241,7 @@ func EditLabel(ctx *context.APIContext) {
 	}
 	l.SetArchived(form.IsArchived != nil && *form.IsArchived)
 	if err := issues_model.UpdateLabel(ctx, l); err != nil {
-		ctx.Error(http.StatusInternalServerError, "UpdateLabel", err)
+		ctx.APIErrorInternal(err)
 		return
 	}
 
@@ -276,8 +276,8 @@ func DeleteLabel(ctx *context.APIContext) {
 	//   "404":
 	//     "$ref": "#/responses/notFound"
 
-	if err := issues_model.DeleteLabel(ctx, ctx.Repo.Repository.ID, ctx.PathParamInt64(":id")); err != nil {
-		ctx.Error(http.StatusInternalServerError, "DeleteLabel", err)
+	if err := issues_model.DeleteLabel(ctx, ctx.Repo.Repository.ID, ctx.PathParamInt64("id")); err != nil {
+		ctx.APIErrorInternal(err)
 		return
 	}
 
