@@ -7,6 +7,7 @@ import (
 	repo_model "code.gitea.io/gitea/models/repo"
 	user_model "code.gitea.io/gitea/models/user"
 	"code.gitea.io/gitea/modules/git"
+	pull_service "code.gitea.io/gitea/services/pull"
 )
 
 // CompareInfo represents the collected results from ParseCompareInfo
@@ -14,7 +15,7 @@ type CompareInfo struct {
 	HeadUser         *user_model.User
 	HeadRepo         *repo_model.Repository
 	HeadGitRepo      *git.Repository
-	CompareInfo      *git.CompareInfo
+	CompareInfo      *pull_service.CompareInfo
 	BaseBranch       string
 	HeadBranch       string
 	DirectComparison bool
