@@ -6,12 +6,12 @@ package repo
 import (
 	"net/http"
 
-	"code.gitea.io/gitea/modules/base"
+	"code.gitea.io/gitea/modules/templates"
 	"code.gitea.io/gitea/services/context"
 )
 
 const (
-	tplRecentCommits base.TplName = "repo/activity"
+	tplRecentCommits templates.TplName = "repo/activity"
 )
 
 // RecentCommits renders the page to show recent commit frequency on repository
