@@ -4,12 +4,11 @@
 package auth
 
 import (
-	"context"
 	"testing"
 
 	"code.gitea.io/gitea/models/unittest"
 	user_model "code.gitea.io/gitea/models/user"
-	"code.gitea.io/gitea/modules/web/middleware"
+	"code.gitea.io/gitea/modules/reqctx"
 	"code.gitea.io/gitea/services/actions"
 
 	"github.com/stretchr/testify/assert"
@@ -23,11 +22,11 @@ func TestUserIDFromToken(t *testing.T) {
 		token, err := actions.CreateAuthorizationToken(RunningTaskID, 1, 2)
 		assert.NoError(t, err)
 
-		ds := make(middleware.ContextData)
+		ds := make(reqctx.ContextData)
 
 		o := OAuth2{}
-		uid := o.userIDFromToken(context.Background(), token, ds)
-		assert.Equal(t, int64(user_model.ActionsUserID), uid)
+		uid := o.userIDFromToken(t.Context(), token, ds)
+		assert.Equal(t, user_model.ActionsUserID, uid)
 		assert.Equal(t, true, ds["IsActionsToken"])
 		assert.Equal(t, ds["ActionsTaskID"], int64(RunningTaskID))
 	})
@@ -48,7 +47,7 @@ func TestCheckTaskIsRunning(t *testing.T) {
 	for name := range cases {
 		c := cases[name]
 		t.Run(name, func(t *testing.T) {
-			actual := CheckTaskIsRunning(context.Background(), c.TaskID)
+			actual := CheckTaskIsRunning(t.Context(), c.TaskID)
 			assert.Equal(t, c.Expected, actual)
 		})
 	}
