@@ -40,7 +40,7 @@ func ToNotificationThread(ctx context.Context, n *activities_model.Notification)
 		if n.Issue != nil {
 			result.Subject.Title = n.Issue.Title
 			result.Subject.URL = n.Issue.APIURL(ctx)
-			result.Subject.HTMLURL = n.Issue.HTMLURL()
+			result.Subject.HTMLURL = n.Issue.HTMLURL(ctx)
 			result.Subject.State = n.Issue.State()
 			comment, err := n.Issue.GetLastComment(ctx)
 			if err == nil && comment != nil {
@@ -53,7 +53,7 @@ func ToNotificationThread(ctx context.Context, n *activities_model.Notification)
 		if n.Issue != nil {
 			result.Subject.Title = n.Issue.Title
 			result.Subject.URL = n.Issue.APIURL(ctx)
-			result.Subject.HTMLURL = n.Issue.HTMLURL()
+			result.Subject.HTMLURL = n.Issue.HTMLURL(ctx)
 			result.Subject.State = n.Issue.State()
 			comment, err := n.Issue.GetLastComment(ctx)
 			if err == nil && comment != nil {
